##  Carpet cleaner conjoint study

A respondent was presented 18 product profiles for a carpet cleaning product described on five attributes in a conjoint study.  The attributes are:

- design = Package Design (A, B, C)
- brand = Brand Name (K2R, Glory, Bissell)
- price = Price (1.19, 1.39, 1.59)
- seal = Good Housekeeping seal of approval (Yes or No)
- money_back = Money Back Guarantee (Yes or No)
- ranking = Respondent ranking of 18 attributes

Based on the attributes, 108 possible profiles could be created (i.e., 3x3x3x2x2 = 108).  The respondent was given a select set of 18 and was asked to rank the profiles from most preferred (rank of 1) to least preferred (rank of 18).  The first five columns represent the five attributes and the last column is the respondent's ranking.